@@ -7,4 +7,4 @@ cf_units = tb[[3]][2][[1]]
 u = lapply(cf_units, as_units, force_single_symbol=TRUE, check_is_valid=FALSE)
 names(u) = substr(tb[[3]][1][[1]], 1, 50)
 # does udunits2 understand them?
-all(sapply(u, udunits2::ud.is.parseable))
+all(sapply(u, units::ud_is_parseable))
